installer

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2026 License: AGPL-3.0 Imports: 32 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Plans = map[string]Plan{
	"Playground": {
		Name:              "Playground",
		Description:       "Suitable for testing and PoC",
		IngestionSpeed:    "Up to 5 MiB/sec",
		CPUAndMemorySpecs: "1 vCPU, 1Gi RAM",
		CPU:               "1",
		Memory:            "1Gi",
		Mode:              "Standalone",
	},
	"Small": {
		Name:              "Small",
		Description:       "Suitable for production grade, small volume workloads",
		IngestionSpeed:    "Up to 20 MiB/sec",
		CPUAndMemorySpecs: "2 vCPUs, 4Gi RAM",
		CPU:               "2",
		Memory:            "4Gi",
		Mode:              "Distributed (1 Query pod, 3 Ingest pod)",
	},
	"Medium": {
		Name:              "Medium",
		IngestionSpeed:    "Up to 50 MiB/sec",
		CPUAndMemorySpecs: "4 vCPUs, 16Gi RAM",
		CPU:               "4",
		Memory:            "18Gi",
		Mode:              "Distributed (1 Query pod, 3 Ingest pod)",
	},
	"Large": {
		Name:              "Large",
		IngestionSpeed:    "Up to 100 MiB/sec",
		CPUAndMemorySpecs: "8 vCPUs, 32Gi RAM",
		CPU:               "8",
		Memory:            "16Gi",
		Mode:              "Distributed (1 Query pod, 3 Ingest pod)",
	},
}

Plans define the plans with clear CPU and memory specs for consumption

Functions

func Installer

func Installer(verbose bool)

func Uninstaller

func Uninstaller(verbose bool) error

Uninstaller uninstalls Parseable from the selected cluster

Types

type Blob

type Blob struct {
	AccessKey          string // Access key for authentication.
	StorageAccountName string // Account name for Azure Blob Storage.
	Container          string // Container name in the Azure Blob store.
	ClientID           string // Client ID to authenticate.
	ClientSecret       string // Client Secret to authenticate.
	TenantID           string // TenantID
	URL                string // URL of the Azure Blob store.
}

Blob contains configuration details for an Azure Blob Storage backend.

type GCS

type GCS struct {
	URL       string // URL of the GCS-compatible object store.
	AccessKey string // Access key for authentication.
	SecretKey string // Secret key for authentication.
	Bucket    string // Bucket name in the GCS store.
	Region    string // Region of the GCS store.
}

GCS contains configuration details for a Google Cloud Storage backend.

type HelmDeploymentConfig

type HelmDeploymentConfig struct {
	ReleaseName string
	Namespace   string
	RepoName    string
	RepoURL     string
	ChartName   string
	Version     string
	Values      []string
	Verbose     bool
}

type ObjectStore

type ObjectStore string

ObjectStore represents the type of object storage backend.

const (
	// S3Store represents an S3-compatible object store.
	S3Store ObjectStore = "s3-store"
	// LocalStore represents a local file system storage backend.
	LocalStore ObjectStore = "local-store"
	// BlobStore represents an Azure Blob Storage backend.
	BlobStore ObjectStore = "blob-store"
	// GcsStore represents a Google Cloud Storage backend.
	GcsStore ObjectStore = "gcs-store"
)

type ObjectStoreConfig

type ObjectStoreConfig struct {
	StorageClass string      // Storage class of the object store.
	ObjectStore  ObjectStore // Type of object store being used.
	S3Store      S3          // S3-specific configuration.
	BlobStore    Blob        // Azure Blob-specific configuration.
	GCSStore     GCS         // GCS-specific configuration.
}

ObjectStoreConfig contains the configuration for the object storage backend.

type ParseableInfo

type ParseableInfo struct {
	Name      string // Name for parseable
	Namespace string // Namespace for parseable
	Username  string // Username for authentication.
	Password  string // Password for authentication.
}

ParseableInfo represents the info used to authenticate, metadata with Parseable.

type Plan

type Plan struct {
	Name              string
	IngestionSpeed    string
	PerDayIngestion   string
	QueryPerformance  string
	CPUAndMemorySpecs string
	CPU               string
	Memory            string
	Mode              string
	Description       string
}

type S3

type S3 struct {
	URL       string // URL of the S3-compatible object store.
	AccessKey string // Access key for authentication.
	SecretKey string // Secret key for authentication.
	Bucket    string // Bucket name in the S3 store.
	Region    string // Region of the S3 store.
}

S3 contains configuration details for an S3-compatible object store.

Jump to